@@ -17,13 +17,14 @@ class Event_Model:
 if __name__ == '__main__':
     import os
     #Test FMS
-    model = Event_Model('FMS', os.getcwd()+'/event/sports/soccer/models/train_FMS.yaml')
-    model.train()
+    # model = 'Seq2Event'
+    # model = Event_Model(model, f'/home/c_yeung/workspace6/python/openstarlab/Event_Pretrain/model_yaml_test/train_{model}_optuna.yaml')
+    # model.train()
     #Example only, run the inference function after training
-    model_path = os.getcwd()+'/test/model/FMS/out/train/20240922-181450/run_1/_model_1.pth'
-    model_config = os.getcwd()+'/test/model/FMS/out/train/20240922-181450/run_1/hyperparameters.json'
-    model.inference(model_path, model_config) #simple inference
-    model.inference(model_path, model_config, simulation=True, random_selection=True, max_iter=20) #simulation with evaluation
-    model = Event_Model('FMS', os.getcwd()+'/event/sports/soccer/models/train_FMS_optuna.yaml')
-    model.train()
-    print('FMS Done')
\ No newline at end of file
+    # model_path = os.getcwd()+'/test/model/FMS/out/train/20240922-181450/run_1/_model_1.pth'
+    # model_config = os.getcwd()+'/test/model/FMS/out/train/20240922-181450/run_1/hyperparameters.json'
+    # model.inference(model_path, model_config) #simple inference
+    # model.inference(model_path, model_config, simulation=True, random_selection=True, max_iter=20) #simulation with evaluation
+    # model = Event_Model('FMS', os.getcwd()+'/event/sports/soccer/models/train_FMS_optuna.yaml')
+    # model.train()
+    print('Done')
\ No newline at end of file
