@@ -46,6 +46,7 @@ class NMSTPP(nn.Module):
         self.linear_action = nn.Linear(self.NN_action_dim, action_output_len) #9
     
     def forward(self, X):
+
         #input features 
         X_action=X[:,:,0]
         X_continuous=X[:,:,1:]
@@ -53,8 +54,9 @@ class NMSTPP(nn.Module):
         #embedding
         X_action = self.action_embedding(X_action.int())
         X_continuous= self.continuous_embedding(X_continuous.float())
+        # print(X_continuous)
         X_concatenate = torch.cat((X_action,X_continuous),2).float()
-
+        # print(X_concatenate)
         #positional encoding
         X_positional = X_concatenate+ self.positional_encoding(X_concatenate)
         X_positional=X_positional.float()
@@ -84,7 +86,6 @@ class NMSTPP(nn.Module):
 
         #output
         out=torch.cat((action_pred,deltaT_pred,location_pred),1)
-        
         return out
     
 class PositionalEncoding(nn.Module):
@@ -200,9 +201,15 @@ def train_NMSTPP(current_time, config, train_df, valid_df, seq_len, features, ep
     loss_save_path = save_path + "_loss.csv"
     hyperparameters_save_path = save_path + "hyperparameters.json"
     model_stats_save_path = save_path + "_model_stats.txt"
+
+    #save the min_dict and max_dict
+    min_max_dict_path = config['save_path']+f"/out/{method}/{current_time}/min_max_dict.json"
+    with open(min_max_dict_path, 'w') as f:
+        json.dump({'min_dict':min_dict, 'max_dict':max_dict}, f, indent=4)
     
     #save all the hyperparameters values
-    hyperparameters = {'train_path': config['train_path'], 'valid_path': config['valid_path'], 'save_path': config['save_path'],
+    hyperparameters = {'current_time': current_time,
+                       'train_path': config['train_path'], 'valid_path': config['valid_path'], 'save_path': config['save_path'],
                         'test': config['test'], 'batch_size': batch_size, 'num_epoch': config['num_epoch'],
                         'print_freq': print_freq, 'early_stop_patience': config['early_stop_patience'],
                         'dataloader_num_worker': config['dataloader_num_worker'], 'device': config['device'], 
@@ -249,7 +256,7 @@ def main(config):
         features = config['basic_features']+config['other_features']
     else:
         seq_len = config['seq_len']
-        epochs = config['epochs']
+        epochs = config['num_epoch']
         if config['use_other_features']:
             features = config['basic_features']+config['other_features']
         else:
@@ -296,10 +303,10 @@ def main_optuna(config):
     if config['test']:
         seq_len = 10
         epochs = 2
-        features = config['basic_features']
+        features = config['basic_features']+config['other_features']
     else:
         seq_len = config['seq_len']
-        epochs = config['epochs']
+        epochs = config['num_epoch']
         if config['use_other_features']:
             features = config['basic_features']+config['other_features']
         else:
@@ -382,7 +389,7 @@ if __name__ == "__main__":
     import yaml
 
     prase = argparse.ArgumentParser()
-    prase.add_argument('--config_path', '-c', type=str, default=os.getcwd()+'/event/sports/soccer/models/train_NMSTPP.yaml')
+    prase.add_argument('--config_path', '-c', type=str, default=os.getcwd()+'/event/sports/soccer/models/model_yaml_test/train_NMSTPP.yaml')
     args = prase.parse_args()
     
     config_path = args.config_path
